#!BPY

"""
Name: 'The Movies Sew Head'
Blender: 249
Group: 'Misc'
Tooltip: 'Attaches .hd imported head mesh to costume .msh at neckconnect'
"""
__author__ = ["Cary Semar"]
__version__ = "1.0  2/18/2020"
__bpydoc__ = """\
 Usage:
    Select the two objects containing neckconnect groups.
    Run this script.  The neck connect vertices in the selected object
    Are moved on top of the neck connect vertices of the active object.
    The first object you click on is the selected object.
    The second object you click on is the active object.
    Afterward, the neckconnect vertices are removed from the neck and head
    vertex groups.

    If you do not select two mesh objects, the script will raise an error.
    If you select an object that does not contain a neckconnect group, the
    script will raise an error.

    The variable threshhold is used to find corresponding neckconnect vertices
    in the mesh.  If after running the script, there is still a gap, increase
    threshhold slightly and run the script again.

"""
import Blender
from Blender import Mathutils as M
from Blender import NMesh
import math
print '\nSewing on the head'
threshhold = .02  #vertices closer than this are pushed together.
def distance(vtx1,vtx2):
        v1 = vtx1.co
        v2 = vtx2.co
        dv = v2-v1
        return math.sqrt(dv*dv)
scn = Blender.Scene.getCurrent()
obj2 = scn.getActiveObject()
if obj2 == None:
        raise ValueError, 'No active object'
objs = Blender.Object.Get()
selected_objects = []
meshes = []
for obj in objs:
#	print obj.type
	if obj.type == 'Mesh':
#		print 'name = ',obj.name
		if obj.isSelected():
                        selected_objects += [obj]
			meshes += [obj.data]
if len(selected_objects) == 0:
        raise ValueError, 'Select two objects'

print 'Active Object:',obj2.name
print 'Selected Objects:',selected_objects
print 'Selected Meshes:',meshes
#for me in meshes:
#        verts = me.verts
#        indices = me.getVertsFromGroup('neckconnect')
#        print 'indices = ',indices
#        for i in indices:
#                vtx = verts[i]
#                print i,vtx.co
#print 'selected_objects[1].name = ',selected_objects[1].name
me = meshes[1]
verts1 = meshes[0].verts
verts2 = meshes[1].verts
indices1 = meshes[0].getVertsFromGroup('neckconnect')
indices2 = meshes[1].getVertsFromGroup('neckconnect')
print 'me=',me
for i in indices1:
        vtx1 = verts1[i]

#        print 'vtx1 = ',vtx1.co
        for j in indices2:
                vtx2 = verts2[j]
                if distance(vtx1,vtx2) < threshhold:
#                        print '     vtx2 = ',vtx2.co,distance(vtx1,vtx2)
                        (x,y,z) = (vtx1.co[0],vtx1.co[1],vtx1.co[2])
                        co = M.Vector(x,y,z)
#                        vtx2.co.x = x
#                        vtx2.co.y = y
#                        vtx2.co.z = z
                        me.verts[j].co.x = x
                        me.verts[j].co.y = y
                        me.verts[j].co.z = z
me.update()
#
# Need to remove neckconnect vertices from neck and head vertex groups for
# head and body.  This should keep the neck and costume vertices from
# separating during an animation.
#
meshes[0].removeVertsFromGroup('neck',indices1)
meshes[0].removeVertsFromGroup('head',indices1)
meshes[1].removeVertsFromGroup('neck',indices2)
meshes[1].removeVertsFromGroup('head',indices2)



                

